@@ -1,5 +1,6 @@
 from distutils.core import setup
-from distutils.extension import Extension
+#from distutils.extension import Extension
+from Pyrex.Distutils.extension import Extension
 from Pyrex.Distutils import build_ext
 
 setup(
